@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 import os
 import sys
 
@@ -10,6 +14,7 @@ if os.name == "nt" or sys.platform == "darwin":
 
 from gi.repository import Gtk, GObject
 
+from quodlibet import _
 from quodlibet.plugins.editing import RenameFilesPlugin
 from quodlibet.util.path import iscommand
 from quodlibet.util import connect_obj
