@@ -1,19 +1,11 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2006 - Steve Frécinaux
+#               2016 - Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 # Parts from "Interactive Python-GTK Console"
 # (stolen from epiphany's console.py)
@@ -37,7 +29,7 @@ from gi.repository import Gtk, Pango, Gdk, GLib
 from quodlibet import _
 from quodlibet import const
 from quodlibet.qltk import Icons
-from quodlibet.compat import exec_
+from quodlibet.compat import exec_, PY2
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.util.collection import Collection
 from quodlibet.util import print_
@@ -77,8 +69,8 @@ class ConsoleWindow(Gtk.Window):
                 'app': app})
         self.add(console)
 
-        acces_string = _("You can access the following objects by default:")
-        acces_string += "\\n".join([
+        access_string = _("You can access the following objects by default:")
+        access_string += "\\n".join([
                         "",
                         "  %5s: SongWrapper objects",
                         "  %5s: Song dictionaries",
@@ -89,12 +81,14 @@ class ConsoleWindow(Gtk.Window):
 
         dir_string = _("Your current working directory is:")
 
+        if PY2:
+            console.eval("from __future__ import print_function", False)
         console.eval("import mutagen", False)
         console.eval("import os", False)
-        console.eval("print \"Python: %s / Quod Libet: %s\"" %
+        console.eval("print(\"Python: %s / Quod Libet: %s\")" %
                      (sys.version.split()[0], const.VERSION), False)
-        console.eval("print \"%s\"" % acces_string, False)
-        console.eval("print \"%s \"+ os.getcwd()" % dir_string, False)
+        console.eval("print(\"%s\")" % access_string, False)
+        console.eval("print(\"%s \"+ os.getcwd())" % dir_string, False)
 
         console.connect("destroy", lambda *x: self.destroy())
 
