@@ -9,6 +9,7 @@
 
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet import util
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.plugins.songshelpers import is_a_file, each_song
@@ -26,9 +27,10 @@ class BurnCD(SongsMenuPlugin):
     plugin_handles = each_song(is_a_file)
 
     burn_programs = {
-        'K3b': ['k3b', '--audiocd'],
-        'Brasero': ['brasero', '--audio'],
-        'Xfburn': ['xfburn', '--audio-composition'],
+        # args, reverse order
+        'K3b': (['k3b', '--audiocd'], False),
+        'Brasero': (['brasero', '--audio'], False),
+        'Xfburn': (['xfburn', '--audio-composition'], True),
     }
 
     def __init__(self, *args, **kwargs):
@@ -36,11 +38,11 @@ class BurnCD(SongsMenuPlugin):
         self.prog_name = None
 
         items = self.burn_programs.items()
-        progs = [(iscommand(x[1][0]), x) for x in items]
+        progs = [(iscommand(x[1][0][0]), x) for x in items]
         progs.sort(reverse=True)
 
         submenu = Gtk.Menu()
-        for (is_cmd, (name, (cmd, arg))) in progs:
+        for (is_cmd, (name, (args, reverse))) in progs:
             item = Gtk.MenuItem(label=name)
             if not is_cmd:
                 item.set_sensitive(False)
@@ -56,5 +58,6 @@ class BurnCD(SongsMenuPlugin):
         if self.prog_name is None:
             return
 
-        cmd, arg = self.burn_programs[self.prog_name]
-        util.spawn([cmd, arg] + [song['~filename'] for song in songs])
+        args, reverse = self.burn_programs[self.prog_name]
+        songs = sorted(songs, key=lambda s: s.sort_key, reverse=reverse)
+        util.spawn(args + [song['~filename'] for song in songs])
