@@ -8,6 +8,7 @@
 
 from gi.repository import Gtk
 
+from quodlibet.compat import listvalues
 from quodlibet.qltk.pluginwin import PluginWindow
 
 from quodlibet import ngettext, _
@@ -24,7 +25,6 @@ from quodlibet.qltk import get_top_parent, get_menu_item_top_parent, Icons
 from quodlibet.plugins import PluginManager, PluginHandler
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.util.songwrapper import ListWrapper, check_wrapper_changed
-from quodlibet.compat import listfilter
 
 
 class ConfirmMultiSongInvoke(WarningMessage):
@@ -127,7 +127,7 @@ class SongsMenuPluginHandler(PluginHandler):
                     print_e("Couldn't initialise song plugin %s. Stack trace:"
                             % Kind)
                     print_exc()
-        items = listfilter(lambda i: i.initialized, items)
+        items = [i for i in items if i.initialized]
 
         if items:
             menu = Gtk.Menu()
@@ -162,7 +162,7 @@ class SongsMenuPluginHandler(PluginHandler):
                 albums[key] = []
             albums[key].append(song)
 
-        albums = albums.values()
+        albums = listvalues(albums)
         for album in albums:
             album.sort()
         return albums
@@ -328,8 +328,7 @@ class SongsMenu(Gtk.Menu):
             from quodlibet.browsers.playlists.menu import PlaylistMenu
             from quodlibet.browsers.playlists import PlaylistsBrowser
             try:
-                submenu = PlaylistMenu(songs, PlaylistsBrowser.playlists(),
-                                       librarian)
+                submenu = PlaylistMenu(songs, PlaylistsBrowser.playlists())
 
                 def on_new(widget, playlist):
                     PlaylistsBrowser.changed(playlist)
@@ -345,7 +344,7 @@ class SongsMenu(Gtk.Menu):
             b = qltk.MenuItem(_("Add to _Queue"), Icons.LIST_ADD)
 
             def enqueue_cb(item, songs):
-                songs = filter(lambda s: s.can_add, songs)
+                songs = [s for s in songs if s.can_add]
                 if songs:
                     from quodlibet import app
                     app.window.playlist.enqueue(songs)
