@@ -7,6 +7,9 @@
 
 from gi.repository import Gtk, GLib, Pango
 
+from senf import fsnative
+
+from quodlibet import _
 from quodlibet import qltk
 from quodlibet import util
 
@@ -15,6 +18,7 @@ from quodlibet.formats import AudioFile
 from quodlibet.pattern import XMLFromPattern, XMLFromMarkupPattern, \
     error as PatternError
 from quodlibet.util import connect_obj, gdecode
+from quodlibet.compat import text_type
 
 try:
     import gi
@@ -88,9 +92,9 @@ def validate_markup_pattern(text, alternative_markup=True, links=False):
         ValueError: In case the pattern isn't valid
     """
 
-    assert isinstance(text, unicode)
+    assert isinstance(text, text_type)
 
-    f = AudioFile({"~filename": "dummy"})
+    f = AudioFile({"~filename": fsnative(u"dummy")})
 
     try:
         if alternative_markup:
