@@ -174,8 +174,10 @@ class TreeViewHints(Gtk.Window):
                     self.__undisplay(send_leave=False)
                     return False
 
-        # hide if any modifier is active
-        if event.get_state() & Gtk.accelerator_get_default_mod_mask():
+        # hide if any modifier is active.
+        mask = Gtk.accelerator_get_default_mod_mask()
+        mask = Gdk.Keymap.get_default().map_virtual_modifiers(mask)[1]
+        if event.get_state() & mask:
             self.__undisplay()
             return False
 
@@ -657,7 +659,13 @@ class BaseView(Gtk.TreeView):
 
         self.connect("button-release-event", on_button_release_event)
 
+    def do_key_press_event(self, event):
+        if is_accel(event, "space", "KP_Space"):
+            return False
+        return Gtk.TreeView.do_key_press_event(self, event)
+
     def __key_pressed(self, view, event):
+
         def get_first_selected():
             selection = self.get_selection()
             model, paths = selection.get_selected_rows()
