@@ -17,6 +17,7 @@ is used and not the release version.
 """
 
 from gi.repository import Gtk
+import feedparser
 
 import quodlibet
 from quodlibet import _
@@ -56,12 +57,6 @@ def fetch_versions(build_type, timeout=5.0):
     Raises UpdateError
     """
 
-    # TODO: we currently don't depend on feedparser.. maybe we should?
-    try:
-        import feedparser
-    except ImportError as error:
-        raise UpdateError(error)
-
     try:
         content = urlopen(
             u"https://quodlibet.github.io/appcast/%s.rss" % build_type,
@@ -149,6 +144,9 @@ class UpdateDialog(Dialog):
             Gtk.Label(label=text, use_markup=True, wrap=True,
                       justify=Gtk.Justification.CENTER))
 
+        button = self.get_widget_for_response(Gtk.ResponseType.CANCEL)
+        button.set_label(_("_Close"))
+
     def _set_widget(self, widget):
         old = self._stack.get_visible_child()
         self._stack.add(widget)
